summaryrefslogtreecommitdiff
path: root/src/mongo/db/storage/sorted_data_interface_test_dupkeycheck.cpp
diff options
context:
space:
mode:
authorMathias Stearn <mathias@10gen.com>2014-11-26 15:04:26 -0500
committerMathias Stearn <mathias@10gen.com>2014-11-26 15:15:59 -0500
commit16a8ef7ad60d498b69bdc0ad5cbca44757d16fd8 (patch)
tree2d9f056acf8f1b9b2e943f82e315bdf019475a38 /src/mongo/db/storage/sorted_data_interface_test_dupkeycheck.cpp
parentcb5cab88761d9aca75e064665cce89f579c69e36 (diff)
downloadmongo-16a8ef7ad60d498b69bdc0ad5cbca44757d16fd8.tar.gz
SERVER-13679 Replace DiskLoc with RecordId outside of MMAPv1
Operations: sed -i -e 's/\<DiskLoc\>/RecordId/g' sed -i -e 's/\<DiskLocs\>/RecordIds/g' sed -i -e 's/\<minDiskLoc\>/RecordId::min()/g' sed -i -e 's/\<maxDiskLoc\>/RecordId::max()/g' sed -i -e 's/\<getDiskLoc\>/getRecordId/g'' Changes under mmap_v1 were reverted and redone by hand as needed.
Diffstat (limited to 'src/mongo/db/storage/sorted_data_interface_test_dupkeycheck.cpp')
-rw-r--r--src/mongo/db/storage/sorted_data_interface_test_dupkeycheck.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/mongo/db/storage/sorted_data_interface_test_dupkeycheck.cpp b/src/mongo/db/storage/sorted_data_interface_test_dupkeycheck.cpp
index b160ae9b56e..a8644536ea2 100644
--- a/src/mongo/db/storage/sorted_data_interface_test_dupkeycheck.cpp
+++ b/src/mongo/db/storage/sorted_data_interface_test_dupkeycheck.cpp
@@ -36,7 +36,7 @@
namespace mongo {
// Insert a key and verify that dupKeyCheck() returns a non-OK status for
// the same key. When dupKeyCheck() is called with the exact (key, DiskLoc)
// pair that was inserted, it should still return an OK status.
TEST( SortedDataInterface, DupKeyCheckAfterInsert ) {
scoped_ptr<HarnessHelper> harnessHelper( newHarnessHelper() );
@@ -66,7 +66,7 @@ namespace mongo {
{
WriteUnitOfWork uow( opCtx.get() );
ASSERT_OK( sorted->dupKeyCheck( opCtx.get(), key1, loc1 ) );
- ASSERT_NOT_OK( sorted->dupKeyCheck( opCtx.get(), key1, minDiskLoc ) );
+ ASSERT_NOT_OK( sorted->dupKeyCheck( opCtx.get(), key1, RecordId::min() ) );
uow.commit();
}
}
@@ -94,7 +94,7 @@ namespace mongo {
}
// Insert a key and verify that dupKeyCheck() acknowledges the duplicate key, even
// when the insert key is located at a DiskLoc that comes after the one specified.
TEST( SortedDataInterface, DupKeyCheckWhenDiskLocBefore ) {
scoped_ptr<HarnessHelper> harnessHelper( newHarnessHelper() );
scoped_ptr<SortedDataInterface> sorted( harnessHelper->newSortedDataInterface( true ) );
@@ -122,14 +122,14 @@ namespace mongo {
scoped_ptr<OperationContext> opCtx( harnessHelper->newOperationContext() );
{
WriteUnitOfWork uow( opCtx.get() );
- ASSERT_NOT_OK( sorted->dupKeyCheck( opCtx.get(), key1, minDiskLoc ) );
+ ASSERT_NOT_OK( sorted->dupKeyCheck( opCtx.get(), key1, RecordId::min() ) );
uow.commit();
}
}
}
// Insert a key and verify that dupKeyCheck() acknowledges the duplicate key, even
// when the insert key is located at a DiskLoc that comes before the one specified.
TEST( SortedDataInterface, DupKeyCheckWhenDiskLocAfter ) {
scoped_ptr<HarnessHelper> harnessHelper( newHarnessHelper() );
scoped_ptr<SortedDataInterface> sorted( harnessHelper->newSortedDataInterface( true ) );
@@ -157,7 +157,7 @@ namespace mongo {
scoped_ptr<OperationContext> opCtx( harnessHelper->newOperationContext() );
{
WriteUnitOfWork uow( opCtx.get() );
- ASSERT_NOT_OK( sorted->dupKeyCheck( opCtx.get(), key1, maxDiskLoc ) );
+ ASSERT_NOT_OK( sorted->dupKeyCheck( opCtx.get(), key1, RecordId::max() ) );
uow.commit();
}
}
@@ -36,7 +36,7 @@
namespace mongo {
// Insert a key and verify that dupKeyCheck() returns a non-OK status for
- // the same key. When dupKeyCheck() is called with the exact (key, DiskLoc)
+ // the same key. When dupKeyCheck() is called with the exact (key, RecordId)
// pair that was inserted, it should still return an OK status.
TEST( SortedDataInterface, DupKeyCheckAfterInsert ) {
@@ -94,7 +94,7 @@ namespace mongo {
}
// Insert a key and verify that dupKeyCheck() acknowledges the duplicate key, even
- // when the insert key is located at a DiskLoc that comes after the one specified.
+ // when the insert key is located at a RecordId that comes after the one specified.
TEST( SortedDataInterface, DupKeyCheckWhenDiskLocBefore ) {
scoped_ptr<HarnessHelper> harnessHelper( newHarnessHelper() );
@@ -122,14 +122,14 @@ namespace mongo {
}
// Insert a key and verify that dupKeyCheck() acknowledges the duplicate key, even
- // when the insert key is located at a DiskLoc that comes before the one specified.
+ // when the insert key is located at a RecordId that comes before the one specified.
TEST( SortedDataInterface, DupKeyCheckWhenDiskLocAfter ) {
scoped_ptr<HarnessHelper> harnessHelper( newHarnessHelper() );